summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Rakefile2
-rw-r--r--lib/hoe.rb11
-rw-r--r--lib/hoe/publish.rb2
-rw-r--r--template/Rakefile.erb2
4 files changed, 10 insertions, 7 deletions
diff --git a/Rakefile b/Rakefile
index 4f064a0..071a1bf 100644
--- a/Rakefile
+++ b/Rakefile
@@ -9,7 +9,7 @@ Hoe.plugin :isolate
Hoe.spec "hoe" do
developer "Ryan Davis", "ryand-ruby@zenspider.com"
- self.rubyforge_name = "seattlerb"
+ self.group_name = "seattlerb"
blog_categories << "Seattle.rb" << "Ruby"
diff --git a/lib/hoe/publish.rb b/lib/hoe/publish.rb
index 1f8f396..abf73f0 100644
--- a/lib/hoe/publish.rb
+++ b/lib/hoe/publish.rb
@@ -192,7 +192,7 @@ module Hoe::Publish
def make_rdoc_cmd(*extra_args) # :nodoc:
title = "#{name}-#{version} Documentation"
- title = "#{rubyforge_name}'s #{title}" if rubyforge_name != name
+ title = "#{group_name}'s #{title}" if group_name != name
rdoc = Gem.bin_wrapper "rdoc"
%W[#{rdoc}
diff --git a/template/Rakefile.erb b/template/Rakefile.erb
index 61c3861..a4e148d 100644
--- a/template/Rakefile.erb
+++ b/template/Rakefile.erb
@@ -16,7 +16,7 @@ Hoe.spec "<%= project %>" do
# developer("<%= XIF %>", "<%= XIF %>@example.com")
- # self.rubyforge_name = "<%= project %>x" # if different than "<%= project %>"
+ # self.group_name = "<%= project %>x" # if part of an organization/group
# license "MIT" # this should match the license in the README
end
diff --git a/lib/hoe.rb b/lib/hoe.rb
index b8daeb7..e15775e 100644
--- a/lib/hoe.rb
+++ b/lib/hoe.rb
@@ -205,9 +205,12 @@ class Hoe
attr_accessor :readme_file
##
- # Optional: The name of the rubyforge project. [default: name.downcase]
+ # Optional: The name of the group authoring the project. [default: name.downcase]
- attr_accessor :rubyforge_name
+ attr_accessor :group_name
+
+ alias :rubyforge_name :group_name # Deprecated. Use #group_name.
+ alias :rubyforge_name= :group_name= # Deprecated. Use #group_name=.
##
# The Gem::Specification.
@@ -528,7 +531,7 @@ class Hoe
else
raise "unknown urls format: #{urls.inspect}"
end
- s.rubyforge_project = rubyforge_name
+ s.rubyforge_project = group_name
s.description = description
s.files = manifest
s.executables = s.files.grep(/^bin/) { |f| File.basename(f) }
@@ -619,7 +622,7 @@ class Hoe
self.extra_rdoc_files = []
self.licenses = []
self.post_install_message = nil
- self.rubyforge_name = name.downcase
+ self.group_name = name.downcase
self.spec = nil
self.spec_extras = {}
self.summary = nil